#!/bin/sh
# mkdb.sh - Create and fill HP Eloquence sample database
#
# Usage: ./mkdb.sh
#
# Please note, that the database server (eloqdb6) process must
# already be active.

# Where HP Eloquence is installed
EQ6=/opt/eloquence6

# default database admin/user id
dba=dba
user=public

# database name and server address
db=sample
host=localhost
service=eloqdb
fqdb=${host}:${service}/$db

# scratch file
tmp_file=/tmp/mkdb.out
trap "rm -f $tmp_file" 0 1 2


### welcome

cat <<EOF

---------------------------------------------------------------
mkdb.sh - Create HP Eloquence sample database
---------------------------------------------------------------

Database: $db
Host    : ${host}
Service : ${service}

EOF


### check if required files are present

if [ ! -f ${db}.schema -o ! -f ${db}.exp ]
then
   echo "mkdb.sh: ${db}.schema or ${db}.exp file missing"
   exit 1
fi

### check if the database server is up
# This will retrieve the list of available data bases

echo "Check if database server is active ..."
res=`$EQ6/bin/dbdumpcat -u ${dba} -h ${host} -s ${service} -t31 2>$tmp_file`
if [ $? != 0 ]; then
   cat << EOF
FAILED: Unable to contact database server.
| The HP Eloquence database server is either not active or
| listening on a different port address.
| Please start the database server process and verify your
| /etc/opt/eloquence6/eloqdb6.cfg configuration file.
--- message log ---
EOF
   cat $tmp_file
   exit 1
fi

### check if database already installed
# hint: installed databases are always uppercase
echo "$res"|sed -e '1,6 d' -e '$ d'|cut -d'|' -f3|
 tr "[A-Z]" "[a-z]"|fgrep -q ${db}
if [ $? == 0 ]; then
   # database already exists ...
   echo "Database ${db} already exists - purging database ..."
   $EQ6/bin/dbpurge -u ${dba} ${fqdb} 2>$tmp_file
   if [ $? != 0 ]; then
      cat <<EOF
FAILED: Unable to purge database ${fqdb}
| The database ${db} may not be in use.
--- message log ---
EOF
      cat $tmp_file
      exit 1
   fi
fi


### transfer database schema to the server
echo "Transfer database schema ..."
$EQ6/bin/schema -t -u ${dba} -h ${host} -s ${service} ${db}.schema 2>$tmp_file
if [ $? != 0 ]; then
      cat <<EOF
FAILED: schema transfer failed.
EOF
   cat $tmp_file
   exit 1
fi


### Create the database
echo "Create database resources ..."
$EQ6/bin/dbcreate -u ${dba} ${fqdb} 2>$tmp_file
if [ $? != 0 ]; then
   cat <<EOF
FAILED: Unable to create database ${fqdb}"
EOF
   cat $tmp_file
   exit 1
fi


### Import sample data
echo "Importing database ..."
$EQ6/bin/dbimport -u ${user} -vs ${db}.exp ${fqdb} 2>$tmp_file
if [ $? != 0 ]; then
   cat <<EOF
FAILED: Data import failed."
EOF
   cat $tmp_file
   exit 1
fi

echo "done."
